drop patches which are included in upstream

This commit is contained in:
Than Ngo 2010-11-02 13:50:09 +01:00
parent dcb992d61b
commit ebdb7525fa
4 changed files with 0 additions and 50 deletions

View File

@ -1,19 +0,0 @@
--- branches/KDE/4.5/kdelibs/plasma/tooltipmanager.cpp 2010/09/28 01:19:58 1180436
+++ branches/KDE/4.5/kdelibs/plasma/tooltipmanager.cpp 2010/10/08 11:35:52 1183776
@@ -236,10 +236,12 @@
}
}
- d->tipWidget->setContent(widget, data);
- d->tipWidget->prepareShowing();
- if (m_corona) {
- d->tipWidget->moveTo(m_corona->popupPosition(widget, d->tipWidget->size(), Qt::AlignCenter));
+ if (d->tipWidget) {
+ d->tipWidget->setContent(widget, data);
+ d->tipWidget->prepareShowing();
+ if (m_corona) {
+ d->tipWidget->moveTo(m_corona->popupPosition(widget, d->tipWidget->size(), Qt::AlignCenter));
+ }
}
}
}

View File

@ -1,14 +0,0 @@
--- kdelibs-4.5.2/kio/kio/krun.cpp.orig 2010/09/07 20:07:19 1172681
+++ kdelibs-4.5.2/kio/kio/krun.cpp 2010/10/06 22:33:23 1183317
@@ -375,6 +375,7 @@
}
else { // if no KDE app, be a bit over-generic
supportedProtocols.append("http");
+ supportedProtocols.append("https"); // #253294
supportedProtocols.append("ftp");
}
}

View File

@ -90,12 +90,8 @@ Patch27: kdelibs-4.4.80-no_rpath.patch
Patch50: kdelibs-4.5.1-knewstuff_gpg2.patch
## 4.5 upstream
Patch100: kdelibs-4.5.2-comic_applet_kde253387.patch
# http://websvn.kde.org/?view=revision&revision=1186278
Patch101: kdelibs-4.5.2-kio_krun_services.patch
## trunk upstream
Patch150: kdelibs-4.5.2-krun-kde#253294.patch
# http://websvn.kde.org/?view=revision&revision=1185912
Patch151: kdelibs-4.5.2-plasma_wallpaper_configchanged.patch
@ -264,9 +260,6 @@ sed -i -e "s|@@VERSION_RELEASE@@|%{version}-%{release}|" kio/kio/kprotocolmanage
%patch50 -p1 -b .knewstuff_gpg2
# upstream patches
%patch100 -p4 -b .comic_applet_kde253387
%patch101 -p4 -b .kio_krun_services
%patch150 -p1 -b .kde#253294
%patch151 -p3 -b .plasma_wallpaper_configchanged
# security fix
--- branches/KDE/4.5/kdelibs/kio/kio/krun.cpp 2010/10/15 15:53:49 1186277
+++ branches/KDE/4.5/kdelibs/kio/kio/krun.cpp 2010/10/15 16:00:27 1186278
@@ -368,9 +368,9 @@
}
else {
if (supportedProtocols.isEmpty()) {
// compat mode: assume KIO if not set and it's a KDE app
const QStringList categories = _service.property("Categories").toStringList();
- if (categories.contains("KDE")) {
+ if (categories.contains("KDE") || !_service.isApplication()) {
supportedProtocols.append("KIO");
}
else { // if no KDE app, be a bit over-generic

View File

@ -1,10 +0,0 @@
@@ -368,9 +368,9 @@
else {
if (supportedProtocols.isEmpty()) {
- // compat mode: assume KIO if not set and it's a KDE app
+ // compat mode: assume KIO if not set and it's a KDE app (or a KDE service)
const QStringList categories = _service.property("Categories").toStringList();